@@ -20,6 +20,7 @@ public:
     void openArticle(QString itemTitle, QString text, bool playlist = false);
     void clearCurrentArticles();
     void setPlaylistFocus();
+    void createAudioForPlaylist(QString title);
     ~Player();
 
 private slots:
@@ -44,6 +45,7 @@ private slots:
 signals:
     void openArticleFromLink(QListWidgetItem *item);
     void audioCreated();
+    void playListFileAdded();
 
 private:
     Ui::Player *ui;
